==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebComboDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebComboDescription = /*@__PURE__*/ (() => {
    class WebComboDescription extends Description {
        constructor() {
            super();
            this.ae = null;
            this.an = null;
            this.k = false;
            this.p = false;
            this.m = false;
            this.o = false;
            this.q = false;
            this.h = false;
            this.i = false;
            this.am = null;
            this.aq = null;
            this.ar = null;
            this.af = null;
            this.n = false;
            this.as = null;
            this.ag = null;
            this.aj = null;
            this.ak = null;
            this.f = null;
            this.j = false;
            this.l = false;
            this.al = null;
            this.ai = null;
            this.ah = null;
            this.ab = null;
            this.ap = null;
            this.ao = null;
            this.ad = null;
            this.ac = null;
        }
        get_type() {
            return "WebCombo";
        }
        get type() {
            return this.get_type();
        }
        get dataRef() {
            return this.ae;
        }
        set dataRef(a) {
            this.ae = a;
            this.e("DataRef");
        }
        get name() {
            return this.an;
        }
        set name(a) {
            this.an = a;
            this.e("Name");
        }
        get disabled() {
            return this.k;
        }
        set disabled(a) {
            this.k = a;
            this.e("Disabled");
        }
        get required() {
            return this.p;
        }
        set required(a) {
            this.p = a;
            this.e("Required");
        }
        get invalid() {
            return this.m;
        }
        set invalid(a) {
            this.m = a;
            this.e("Invalid");
        }
        get outlined() {
            return this.o;
        }
        set outlined(a) {
            this.o = a;
            this.e("Outlined");
        }
        get singleSelect() {
            return this.q;
        }
        set singleSelect(a) {
            this.q = a;
            this.e("SingleSelect");
        }
        get autofocus() {
            return this.h;
        }
        set autofocus(a) {
            this.h = a;
            this.e("Autofocus");
        }
        get autofocusList() {
            return this.i;
        }
        set autofocusList(a) {
            this.i = a;
            this.e("AutofocusList");
        }
        get label() {
            return this.am;
        }
        set label(a) {
            this.am = a;
            this.e("Label");
        }
        get placeholder() {
            return this.aq;
        }
        set placeholder(a) {
            this.aq = a;
            this.e("Placeholder");
        }
        get placeholderSearch() {
            return this.ar;
        }
        set placeholderSearch(a) {
            this.ar = a;
            this.e("PlaceholderSearch");
        }
        get dir() {
            return this.af;
        }
        set dir(a) {
            this.af = a;
            this.e("Dir");
        }
        get open() {
            return this.n;
        }
        set open(a) {
            this.n = a;
            this.e("Open");
        }
        get valueKey() {
            return this.as;
        }
        set valueKey(a) {
            this.as = a;
            this.e("ValueKey");
        }
        get displayKey() {
            return this.ag;
        }
        set displayKey(a) {
            this.ag = a;
            this.e("DisplayKey");
        }
        get groupKey() {
            return this.aj;
        }
        set groupKey(a) {
            this.aj = a;
            this.e("GroupKey");
        }
        get groupSorting() {
            return this.ak;
        }
        set groupSorting(a) {
            this.ak = a;
            this.e("GroupSorting");
        }
        get filteringOptions() {
            return this.f;
        }
        set filteringOptions(a) {
            this.f = a;
            this.e("FilteringOptions");
        }
        get caseSensitiveIcon() {
            return this.j;
        }
        set caseSensitiveIcon(a) {
            this.j = a;
            this.e("CaseSensitiveIcon");
        }
        get disableFiltering() {
            return this.l;
        }
        set disableFiltering(a) {
            this.l = a;
            this.e("DisableFiltering");
        }
        get itemTemplateRef() {
            return this.al;
        }
        set itemTemplateRef(a) {
            this.al = a;
            this.e("ItemTemplateRef");
        }
        get groupHeaderTemplateRef() {
            return this.ai;
        }
        set groupHeaderTemplateRef(a) {
            this.ai = a;
            this.e("GroupHeaderTemplateRef");
        }
        get focusRef() {
            return this.ah;
        }
        set focusRef(a) {
            this.ah = a;
            this.e("FocusRef");
        }
        get blurRef() {
            return this.ab;
        }
        set blurRef(a) {
            this.ab = a;
            this.e("BlurRef");
        }
        get openingRef() {
            return this.ap;
        }
        set openingRef(a) {
            this.ap = a;
            this.e("OpeningRef");
        }
        get openedRef() {
            return this.ao;
        }
        set openedRef(a) {
            this.ao = a;
            this.e("OpenedRef");
        }
        get closingRef() {
            return this.ad;
        }
        set closingRef(a) {
            this.ad = a;
            this.e("ClosingRef");
        }
        get closedRef() {
            return this.ac;
        }
        set closedRef(a) {
            this.ac = a;
            this.e("ClosedRef");
        }
    }
    WebComboDescription.$t = /*@__PURE__*/ markType(WebComboDescription, 'WebComboDescription', Description.$);
    return WebComboDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebComboDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebComboDescription = /*@__PURE__*/ (() => {
    class WebComboDescription extends Description {
        get_type() {
            return "WebCombo";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.al = null;
            this.s = false;
            this.u = false;
            this.l = false;
            this.m = false;
            this.as = null;
            this.aw = null;
            this.ax = null;
            this.r = false;
            this.ay = null;
            this.am = null;
            this.ap = null;
            this.aq = null;
            this.j = null;
            this.n = false;
            this.p = false;
            this.h = null;
            this.o = false;
            this.t = false;
            this.af = null;
            this.at = null;
            this.q = false;
            this.ar = null;
            this.ao = null;
            this.ai = null;
            this.an = null;
            this.ah = null;
            this.av = null;
            this.au = null;
            this.ak = null;
            this.aj = null;
        }
        get dataRef() {
            return this.al;
        }
        set dataRef(a) {
            this.al = a;
            this.g("DataRef");
        }
        get outlined() {
            return this.s;
        }
        set outlined(a) {
            this.s = a;
            this.g("Outlined");
        }
        get singleSelect() {
            return this.u;
        }
        set singleSelect(a) {
            this.u = a;
            this.g("SingleSelect");
        }
        get autofocus() {
            return this.l;
        }
        set autofocus(a) {
            this.l = a;
            this.g("Autofocus");
        }
        get autofocusList() {
            return this.m;
        }
        set autofocusList(a) {
            this.m = a;
            this.g("AutofocusList");
        }
        get label() {
            return this.as;
        }
        set label(a) {
            this.as = a;
            this.g("Label");
        }
        get placeholder() {
            return this.aw;
        }
        set placeholder(a) {
            this.aw = a;
            this.g("Placeholder");
        }
        get placeholderSearch() {
            return this.ax;
        }
        set placeholderSearch(a) {
            this.ax = a;
            this.g("PlaceholderSearch");
        }
        get open() {
            return this.r;
        }
        set open(a) {
            this.r = a;
            this.g("Open");
        }
        get valueKey() {
            return this.ay;
        }
        set valueKey(a) {
            this.ay = a;
            this.g("ValueKey");
        }
        get displayKey() {
            return this.am;
        }
        set displayKey(a) {
            this.am = a;
            this.g("DisplayKey");
        }
        get groupKey() {
            return this.ap;
        }
        set groupKey(a) {
            this.ap = a;
            this.g("GroupKey");
        }
        get groupSorting() {
            return this.aq;
        }
        set groupSorting(a) {
            this.aq = a;
            this.g("GroupSorting");
        }
        get filteringOptions() {
            return this.j;
        }
        set filteringOptions(a) {
            this.j = a;
            this.g("FilteringOptions");
        }
        get caseSensitiveIcon() {
            return this.n;
        }
        set caseSensitiveIcon(a) {
            this.n = a;
            this.g("CaseSensitiveIcon");
        }
        get disableFiltering() {
            return this.p;
        }
        set disableFiltering(a) {
            this.p = a;
            this.g("DisableFiltering");
        }
        get value() {
            return this.h;
        }
        set value(a) {
            this.h = a;
            this.g("Value");
        }
        get disabled() {
            return this.o;
        }
        set disabled(a) {
            this.o = a;
            this.g("Disabled");
        }
        get required() {
            return this.t;
        }
        set required(a) {
            this.t = a;
            this.g("Required");
        }
        get defaultValue() {
            return this.af;
        }
        set defaultValue(a) {
            this.af = a;
            this.g("DefaultValue");
        }
        get name() {
            return this.at;
        }
        set name(a) {
            this.at = a;
            this.g("Name");
        }
        get invalid() {
            return this.q;
        }
        set invalid(a) {
            this.q = a;
            this.g("Invalid");
        }
        get itemTemplateRef() {
            return this.ar;
        }
        set itemTemplateRef(a) {
            this.ar = a;
            this.g("ItemTemplateRef");
        }
        get groupHeaderTemplateRef() {
            return this.ao;
        }
        set groupHeaderTemplateRef(a) {
            this.ao = a;
            this.g("GroupHeaderTemplateRef");
        }
        get changeRef() {
            return this.ai;
        }
        set changeRef(a) {
            this.ai = a;
            this.g("ChangeRef");
        }
        get focusRef() {
            return this.an;
        }
        set focusRef(a) {
            this.an = a;
            this.g("FocusRef");
        }
        get blurRef() {
            return this.ah;
        }
        set blurRef(a) {
            this.ah = a;
            this.g("BlurRef");
        }
        get openingRef() {
            return this.av;
        }
        set openingRef(a) {
            this.av = a;
            this.g("OpeningRef");
        }
        get openedRef() {
            return this.au;
        }
        set openedRef(a) {
            this.au = a;
            this.g("OpenedRef");
        }
        get closingRef() {
            return this.ak;
        }
        set closingRef(a) {
            this.ak = a;
            this.g("ClosingRef");
        }
        get closedRef() {
            return this.aj;
        }
        set closedRef(a) {
            this.aj = a;
            this.g("ClosedRef");
        }
    }
    WebComboDescription.$t = /*@__PURE__*/ markType(WebComboDescription, 'WebComboDescription', Description.$);
    return WebComboDescription;
})();
